3 ms·
I've changed the algorithm to not send fScore updates and treat each branch as independent. This speeds it up from 16 seconds to 320 milliseconds. I am thinkin
by samsquire 3y ago
I've changed the algorithm to not send fScore updates and treat each branch as independent.
This speeds it up from 16 seconds to 320 milliseconds. I am thinking how to make the algorithm scale, by creating better and alternative program candidates in each thread.